@@ -13,13 +13,15 @@ sub build_oauth2_request {
 
   my $store = $controller->store;
   my $req;
-
   try {
     $req = CatalystX::OAuth2::Request::GrantAuth->new(
       %{ $c->req->query_parameters } );
     $req->store($store);
+    $req->user($c->user) if $c->user_exists;
   }
   catch {
+    $c->log->error($_);
+
     # need to figure out a better way, but this will do for now
     $c->res->body('warning: response_type/client_id invalid or missing');
 
@@ -32,6 +34,7 @@ sub build_oauth2_request {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -40,7 +43,7 @@ Catalyst::ActionRole::OAuth2::GrantAuth - Authorization grant endpoint for OAuth
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 SYNOPSIS
 
@@ -81,10 +84,9 @@ Eden Cardim <edencardim@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Suretec Systems Ltd.
+This software is copyright (c) 2015 by Suretec Systems Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
