@@ -6,8 +6,8 @@ use Moose::Role;
 
 requires '_build_query_parameters';
 
-# spec isn't clear re missing endpoint uris, being strict for now
-has redirect_uri  => ( is => 'ro', required => 1 );
+# spec isn't clear re missing endpoint uris
+has redirect_uri  => ( is => 'ro', required => 0 );
 
 has store => (
   is        => 'rw',
@@ -37,6 +37,7 @@ sub BUILD {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -45,7 +46,7 @@ CatalystX::OAuth2 - OAuth2 services for Catalyst
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 SYNOPSIS
 
@@ -173,9 +174,11 @@ The entity representing the client in your schema
 
 =head1 SPONSORSHIP
 
-This module exists due to the wonderful people at Suretec Systems
-Ltd. <http://www.suretecsystems.com/> who sponsored it's development for its
-VoIP division called SureVoIP <http://www.surevoip.co.uk/>
+This module exists due to the wonderful people at Suretec Systems Ltd.
+<http://www.suretecsystems.com/> who sponsored its development for its
+VoIP division called SureVoIP <http://www.surevoip.co.uk/> for use with
+the SureVoIP API - 
+<http://www.surevoip.co.uk/support/wiki/api_documentation>
 
 =head1 AUTHOR
 
@@ -183,10 +186,9 @@ Eden Cardim <edencardim@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Suretec Systems Ltd.
+This software is copyright (c) 2015 by Suretec Systems Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
