@@ -17,11 +17,12 @@ around BUILDARGS => sub {
   my ($app) = @_;
   for ( $args->{store} ) {
     last unless defined and ref eq 'HASH';
-    my $class = delete $_->{class};
+    my $store_args = {%$_};
+    my $class = delete $store_args->{class};
     $class = "CatalystX::OAuth2::Store::$class" unless $class =~ /^\+/;
     my ( $is_success, $error ) = Class::Load::try_load_class($class);
     die qq{Couldn't load OAuth2 store '$class': $error} unless $is_success;
-    $args->{store} = $class->new( %$_, app => $app );
+    $args->{store} = $class->new( %$store_args, app => $app );
   }
   return $args;
 };
@@ -29,6 +30,7 @@ around BUILDARGS => sub {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -37,7 +39,7 @@ CatalystX::OAuth2::Controller::Role::WithStore - A role for providing oauth2 sto
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 AUTHOR
 
@@ -45,10 +47,9 @@ Eden Cardim <edencardim@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Suretec Systems Ltd.
+This software is copyright (c) 2015 by Suretec Systems Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
