@@ -7,9 +7,14 @@ with 'CatalystX::OAuth2';
 # ABSTRACT: An oauth2 authentication token implementation
 
 has grant_type => ( is => 'ro', required => 1 );
-has code  => ( is => 'ro', required => 1 );
+has code       => ( is => 'ro', required => 1 );
+has refresh_token => (
+  isa     => 'Bool',
+  is      => 'rw',
+  default => 0
+);
 
-around _params => sub {shift->(@_), qw(code grant_type)};
+around _params => sub { shift->(@_), qw(code grant_type) };
 
 sub _build_query_parameters {
   my ($self) = @_;
@@ -23,17 +28,23 @@ sub _build_query_parameters {
       . 'or was issued to another client.'
     };
 
-  my $token = $self->store->create_access_token($self->code);
-  return {
+  my $with_refresh = $self->refresh_token;
+  my $token = $self->store->create_access_token( $self->code, $with_refresh );
+  my $res   = {
     access_token => $token->as_string,
     token_type   => $token->type,
-    expires_in   => $token->expires_in
+    expires_in   => $token->expires_in,
   };
+  $res->{refresh_token} = $token->to_refresh_token->as_string
+    if $with_refresh;
+
+  return $res;
 }
 
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -42,7 +53,7 @@ CatalystX::OAuth2::Request::AuthToken - An oauth2 authentication token implement
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 AUTHOR
 
@@ -50,10 +61,9 @@ Eden Cardim <edencardim@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Suretec Systems Ltd.
+This software is copyright (c) 2015 by Suretec Systems Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
