@@ -6,7 +6,7 @@ with 'CatalystX::OAuth2';
 # ABSTRACT: The oauth2 refresh token
 
 has grant_type    => ( is => 'ro', required => 1 );
-has refresh_token => ( is => 'ro', required => 1 );
+has refresh_token => ( is       => 'ro' );
 
 around _params => sub { shift->(@_), qw(grant_type refresh_token) };
 
@@ -23,7 +23,8 @@ sub _build_query_parameters {
     };
 
   my $token =
-    $self->store->create_access_token_from_refresh( $self->refresh_token );
+    $self->store->create_access_token_from_refresh( $self->refresh_token )
+    or return { error => 'internal_error' };
   return {
     access_token => $token->as_string,
     token_type   => $token->type,
@@ -34,6 +35,7 @@ sub _build_query_parameters {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -42,7 +44,7 @@ CatalystX::OAuth2::Request::RefreshToken - The oauth2 refresh token
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 AUTHOR
 
@@ -50,10 +52,9 @@ Eden Cardim <edencardim@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Suretec Systems Ltd.
+This software is copyright (c) 2015 by Suretec Systems Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
