@@ -12,13 +12,14 @@ requires qw(
   deactivate_client_code
   create_access_token
   find_client_code
-  verify_access_secret
+  verify_client_secret
   verify_client_token
 );
 
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -27,7 +28,7 @@ CatalystX::OAuth2::Store - The API for oauth2 stores
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 AUTHOR
 
@@ -35,10 +36,9 @@ Eden Cardim <edencardim@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Suretec Systems Ltd.
+This software is copyright (c) 2015 by Suretec Systems Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
