@@ -85,60 +85,57 @@ sub client_code_is_active {
 }
 
 sub create_access_token {
-  my ( $self, $code ) = @_;
+  my ( $self, $code, $with_refresh ) = @_;
   my $code_row = $self->find_client_code($code)
     or return;
-  return $code_row->related_resultset( $self->token_relation )->create( {} );
-}
-
-sub create_access_token_from_refresh {
-  my ( $self, $refresh ) = @_;
-  my $refresh_row =
-    $self->_client_model->related_resultset( $self->refresh_relation )
-    ->find($refresh)
-    or return;
-  my $code_row =
-    $refresh_row->client->codes->search( { is_active => 1 } )->first
-    or return;
+  return $code_row->related_resultset( $self->token_relation )->create( {} )
+    unless $with_refresh;
   my $token;
-  $code_row->result_source->storage->txn_do(
+  $code_row->result_source->storage->dbh_do(
     sub {
-      $token =
-        $code_row->related_resultset( $self->token_relation )->create( {} );
-      $refresh_row->update( { is_active => 0, access_token => $token } );
+      my $refresh = $code_row->related_resultset( $self->refresh_relation )->create( {} );
+      $token = $refresh->create_access_token;
     }
   );
   return $token;
 }
 
-sub find_code_from_refresh {
+sub create_access_token_from_refresh {
   my ( $self, $refresh ) = @_;
-  my $refresh_row =
-    $self->_client_model->related_resultset( $self->refresh_relation )
-    ->find($refresh)
+  my $refresh_row = $self->_client_model->find_refresh($refresh)
     or return;
-  return $refresh_row->client->codes->search( { is_active => 1 } )->first;
+  return $refresh_row->create_access_token;
 }
 
-sub verify_access_secret {
+sub find_code_from_refresh {
+  my ( $self, $refresh ) = @_;
+  my $refresh_row = $self->_client_model->find_refresh($refresh)
+    or return;
+  return $refresh_row->code;
+}
+
+sub verify_client_secret {
   my ( $self, $client_id, $access_secret ) = @_;
   my $client = $self->find_client($client_id);
-  return $client->access_secret eq $access_secret;
+  return $client->client_secret eq $access_secret;
 }
 
 sub verify_client_token {
-  my ( $self, $client_id, $access_token ) = @_;
-  my $client = $self->find_client($client_id);
+  my ( $self, $access_token ) = @_;
+  my $rs = $self->_client_model;
   return 0 unless defined $access_token;
-  return 1
-    if $client->related_resultset( $self->code_relation )
-      ->related_resultset( $self->token_relation )->find($access_token);
+  my $token_rs = $rs->related_resultset( $self->code_relation )
+    ->related_resultset( $self->token_relation );
+  if(my $token = $token_rs->find($access_token)) {
+    return $token;
+  }
   return 0;
 }
 
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -147,7 +144,7 @@ CatalystX::OAuth2::Store::DBIC - An interface to a DBIC-based OAuth2 store
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 AUTHOR
 
@@ -155,10 +152,9 @@ Eden Cardim <edencardim@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Suretec Systems Ltd.
+This software is copyright (c) 2015 by Suretec Systems Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
